summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlrole.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlrole.h')
-rw-r--r--umbrello/umbrello/umlrole.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/umlrole.h b/umbrello/umbrello/umlrole.h
index 4d750751..464e264e 100644
--- a/umbrello/umbrello/umlrole.h
+++ b/umbrello/umbrello/umlrole.h
@@ -31,10 +31,10 @@ public:
* Sets up an association.
*
* @param tqparent The tqparent (association) of this UMLRole.
* @param tqparentUMLObject The Parent UML Object of this UMLRole
* @param role The Uml::Role_Type of this UMLRole
*/
- UMLRole (UMLAssociation * tqparent, UMLObject * tqparentUMLObject, Uml::Role_Type role);
+ UMLRole (UMLAssociation * tqparent, UMLObject * parentUMLObject, Uml::Role_Type role);
/**
* Overloaded '==' operator
@@ -118,7 +118,7 @@ protected:
private:
/** do some initialization at construction time */
- void init (UMLAssociation * tqparent, UMLObject * tqparentObj, Uml::Role_Type r);
+ void init (UMLAssociation * tqparent, UMLObject * parentObj, Uml::Role_Type r);
UMLAssociation * m_pAssoc;
Uml::Role_Type m_role;
@@ -31,10 +31,10 @@ public:
*
* @param tqparent The tqparent (association) of this UMLRole.
- * @param tqparentUMLObject The Parent UML Object of this UMLRole
+ * @param parentUMLObject The Parent UML Object of this UMLRole
* @param role The Uml::Role_Type of this UMLRole
*/